@@ -8,7 +8,7 @@
 #
 from detector_connector import DetectorHttpConnector
 
-from pollution_detector_connector.pollution_setting import PollutionSetting
+from pollution_detector_connector.pollution_settings import PollutionSettings
 
 
 class PollutionDetectorHttpConnector(DetectorHttpConnector):
@@ -16,4 +16,4 @@ class PollutionDetectorHttpConnector(DetectorHttpConnector):
     Config = DetectorHttpConnector.Config
 
     def __init__(self, config: Config, context: Context) -> None:
-        super().__init__(config=config, context=context, detector_settings_type=PollutionSetting)
+        super().__init__(config=config, context=context, detector_settings_type=PollutionSettings)
