@@ -22,5 +22,5 @@ class ImageBox:
 
 @dataclass(kw_only=True, frozen=True)
 class PollutionSettings(DetectorSettings):
-    locked: float | None = None
+    locked_at: float | None = None
     ignored_image_boxes: list[ImageBox] = field(default_factory=list)
